@@ -5,20 +5,20 @@ use super::*;
 pub enum StyleKind {
     Plain = 0,
 
-    Italic = 11,
-    Strong = 12,
-    Emphasis = 13,
+    Emphasis = 11,
+    Strong = 13,
+    ItalicBold = 14,
 
     Underline = 21,
     Undercover = 22,
-    Highlight = 23,
+    Marking = 23,
     Color(u8, u8, u8, u8) = 24,
     // HTMLColor(String) = 25,
     Delete = 31,
     Insert = 32,
 
-    Sub = 41,
-    Super = 42,
+    Subscript = 41,
+    Superscript = 42,
 }
 
 #[derive(Clone, Debug, Eq, PartialEq, Hash)]
@@ -30,9 +30,9 @@ pub struct StyleNode {
 impl From<&str> for StyleKind {
     fn from(style: &str) -> Self {
         match style {
-            "*" | "i" | "italic" => Self::Italic,
+            "*" | "i" | "italic" | "em" => Self::Emphasis,
             "**" | "b" | "bold" => Self::Strong,
-            "***" | "em" => Self::Emphasis,
+            "***" => Self::ItalicBold,
             "~" | "u" | "underline" => Self::Underline,
             "~~" | "s" => Self::Delete,
             "~~~" => Self::Undercover,
@@ -45,39 +45,13 @@ impl StyleKind {
     pub fn surround_in(&self) -> &'static str {
         match self {
             Self::Plain => "",
-            Self::Italic => "*",
+            Self::Emphasis => "*",
             Self::Strong => "**",
-            Self::Emphasis => "***",
+            Self::ItalicBold => "***",
             Self::Underline => "~",
             Self::Delete => "~~",
             Self::Undercover => "~~~",
-            Self::Highlight => {
-                unimplemented!()
-            }
-            Self::Insert => {
-                unimplemented!()
-            }
-            StyleKind::Color(_, _, _, _) => {
-                unimplemented!()
-            }
-            StyleKind::Sub => {
-                unimplemented!()
-            }
-            StyleKind::Super => {
-                unimplemented!()
-            }
-        }
-    }
-    pub fn surround_out(&self) -> &'static str {
-        match self {
-            Self::Plain => "",
-            Self::Italic => "*",
-            Self::Strong => "**",
-            Self::Emphasis => "***",
-            Self::Underline => "~",
-            Self::Delete => "~~",
-            Self::Undercover => "~~~",
-            Self::Highlight => {
+            Self::Marking => {
                 unimplemented!()
             }
             Self::Insert => {
@@ -86,12 +60,30 @@ impl StyleKind {
             Self::Color(_, _, _, _) => {
                 unimplemented!()
             }
-            Self::Sub => {
+            Self::Subscript => "<sub>",
+            Self::Superscript => "<sup>",
+        }
+    }
+    pub fn surround_out(&self) -> &'static str {
+        match self {
+            Self::Plain => "",
+            Self::Emphasis => "*",
+            Self::Strong => "**",
+            Self::ItalicBold => "***",
+            Self::Underline => "~",
+            Self::Delete => "~~",
+            Self::Undercover => "~~~",
+            Self::Marking => {
                 unimplemented!()
             }
-            Self::Super => {
-                "<super/>"
+            Self::Insert => {
+                unimplemented!()
             }
+            Self::Color(_, _, _, _) => {
+                unimplemented!()
+            }
+            Self::Subscript => "</sub>",
+            Self::Superscript => "</sup>",
         }
     }
 }
@@ -106,3 +98,39 @@ impl StyleNode {
         Self { kind: StyleKind::from(style), children }
     }
 }
+
+macro_rules! styled_node {
+    ($name:tt => $t:tt) => {
+        impl StyleNode {
+            #[inline]
+            pub fn $name(children: ASTNodes) -> Self {
+                Self { kind: StyleKind::$t, children }
+            }
+        }
+
+        impl ASTKind {
+            #[inline]
+            pub fn $name(children: ASTNodes, range: Option<OffsetRange>) -> ASTNode {
+                StyleNode::$name(children).into_node(range)
+            }
+        }
+    };
+    ($($name:tt => $t:tt),+ $(,)?) => (
+        $(styled_node!($name=>$t);)+
+    );
+}
+
+styled_node![
+    bold        => Strong,
+    strong      => Strong,
+    italic      => Emphasis,
+    emphasis    => Emphasis,
+    italic_bold => ItalicBold,
+    marking     => Marking,
+    underline   => Underline,
+    undercover  => Undercover,
+    delete      => Delete,
+    insert      => Insert,
+    subscript   => Subscript,
+    superscript => Superscript,
+];
